@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
 $EXTRACTRC `find . -name "*.ui" -o -name "*.rc"` >> rc.cpp
-$XGETTEXT `find . -name "*.cpp"` -o $podir/xdg-desktop-portal-kde.pot
+$XGETTEXT `find . -name "*.cpp" -o -name "*.qml"` -o $podir/xdg-desktop-portal-kde.pot
 rm -f rc.cpp
