@@ -9,6 +9,8 @@
 #ifndef XDG_DESKTOP_PORTAL_KDE_FILECHOOSER_H
 #define XDG_DESKTOP_PORTAL_KDE_FILECHOOSER_H
 
+#include "dbushelpers.h"
+
 #include <QCheckBox>
 #include <QComboBox>
 #include <QDBusAbstractAdaptor>
@@ -21,6 +23,7 @@
 class KFileWidget;
 class QDialogButtonBox;
 class MobileFileDialog;
+class QDBusMessage;
 
 class FileDialog : public QDialog
 {
@@ -56,36 +59,26 @@ public:
     } FilterList;
     typedef QList<FilterList> FilterListList;
 
-    typedef struct {
-        QString id;
-        QString value;
-    } Choice;
-    typedef QList<Choice> Choices;
-
-    typedef struct {
-        QString id;
-        QString label;
-        Choices choices;
-        QString initialChoiceId;
-    } Option;
-    typedef QList<Option> OptionList;
-
     explicit FileChooserPortal(QObject *parent);
 
 public Q_SLOTS:
-    uint OpenFile(const QDBusObjectPath &handle,
+    void OpenFile(const QDBusObjectPath &handle,
                   const QString &app_id,
                   const QString &parent_window,
                   const QString &title,
                   const QVariantMap &options,
-                  QVariantMap &results);
+                  const QDBusMessage &message,
+                  uint &replyResponse,
+                  QVariantMap &replyResults);
 
-    uint SaveFile(const QDBusObjectPath &handle,
+    void SaveFile(const QDBusObjectPath &handle,
                   const QString &app_id,
                   const QString &parent_window,
                   const QString &title,
                   const QVariantMap &options,
-                  QVariantMap &results);
+                  const QDBusMessage &message,
+                  uint &replyResponse,
+                  QVariantMap &replyResults);
 
 private:
     static QWidget *CreateChoiceControls(const OptionList &optionList, QMap<QString, QCheckBox *> &checkboxes, QMap<QString, QComboBox *> &comboboxes);
