@@ -179,8 +179,11 @@ std::pair<PortalResponse::Response, QVariantMap> continueStart(RemoteDesktopSess
             const QString outputName = session->appId().isEmpty()
                 ? i18n("Virtual Output")
                 : i18nc("%1 is the application name", "Virtual Output (shared with %1)", Utils::applicationName(session->appId()));
-            auto stream = WaylandIntegration::startStreamingVirtual(OutputsModel::virtualScreenIdForApp(session->appId()), outputName, {1920, 1080}, Screencasting::Metadata);
-            if (!stream.isValid()) {
+            auto stream = WaylandIntegration::startStreamingVirtual(OutputsModel::virtualScreenIdForApp(session->appId()),
+                                                                    outputName,
+                                                                    {1920, 1080},
+                                                                    Screencasting::CursorMode(session->cursorMode()));
+            if (!stream.isValid() || !guardedSession) {
                 return {PortalResponse::OtherError, {}};
             }
             streams << stream;
@@ -188,14 +191,14 @@ std::pair<PortalResponse::Response, QVariantMap> continueStart(RemoteDesktopSess
             const auto screens = qGuiApp->screens();
             if (session->multipleSources() || screens.count() == 1) {
                 for (const auto &screen : screens) {
-                    auto stream = WaylandIntegration::startStreamingOutput(screen, Screencasting::Metadata);
-                    if (!stream.isValid()) {
+                    auto stream = WaylandIntegration::startStreamingOutput(screen, Screencasting::CursorMode(session->cursorMode()));
+                    if (!stream.isValid() || !guardedSession) {
                         return {PortalResponse::OtherError, {}};
                     }
                     streams << stream;
                 }
             } else {
-                streams << WaylandIntegration::startStreamingWorkspace(Screencasting::Metadata);
+                streams << WaylandIntegration::startStreamingWorkspace(Screencasting::CursorMode(session->cursorMode()));
             }
         }
 
