@@ -12,10 +12,13 @@
 #include <QDBusAbstractAdaptor>
 #include <QDBusObjectPath>
 
+class QDBusMessage;
+
 class ScreenshotPortal : public QDBusAbstractAdaptor
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.freedesktop.impl.portal.Screenshot")
+    Q_PROPERTY(uint version READ version CONSTANT)
 public:
     struct ColorRGB {
         double red;
@@ -26,8 +29,19 @@ public:
     explicit ScreenshotPortal(QObject *parent);
     ~ScreenshotPortal() override;
 
+    uint version() const
+    {
+        return 2;
+    }
+
 public Q_SLOTS:
-    uint Screenshot(const QDBusObjectPath &handle, const QString &app_id, const QString &parent_window, const QVariantMap &options, QVariantMap &results);
+    void Screenshot(const QDBusObjectPath &handle,
+                    const QString &app_id,
+                    const QString &parent_window,
+                    const QVariantMap &options,
+                    const QDBusMessage &message,
+                    uint &replyResponse,
+                    QVariantMap &replyResults);
 
     uint PickColor(const QDBusObjectPath &handle, const QString &app_id, const QString &parent_window, const QVariantMap &options, QVariantMap &results);
 };
