@@ -172,11 +172,10 @@ ScreenCastSession::ScreenCastSession(QObject *parent, const QString &appId, cons
     m_item->setIconByName(iconName);
 
     auto menu = new QMenu;
-    auto stopAction = new QAction(QIcon::fromTheme(QStringLiteral("process-stop")), i18nc("@action:inmenu stops screen/window sharing", "End"));
+    auto stopAction = menu->addAction(QIcon::fromTheme(QStringLiteral("process-stop")), i18nc("@action:inmenu stops screen/window sharing", "End"));
     connect(stopAction, &QAction::triggered, this, &Session::close);
-    connect(m_item, &KStatusNotifierItem::activateRequested, menu, &QMenu::show);
-    menu->addAction(stopAction);
     m_item->setContextMenu(menu);
+    m_item->setIsMenu(true);
 }
 
 ScreenCastSession::~ScreenCastSession()
@@ -217,6 +216,7 @@ void ScreenCastSession::setOptions(const QVariantMap &options)
 RemoteDesktopSession::RemoteDesktopSession(QObject *parent, const QString &appId, const QString &path)
     : ScreenCastSession(parent, appId, path, QStringLiteral("krfb"))
     , m_screenSharingEnabled(false)
+    , m_clipboardEnabled(false)
 {
     connect(this, &RemoteDesktopSession::closed, this, [this] {
         if (m_acquired) {
@@ -257,6 +257,16 @@ void RemoteDesktopSession::setScreenSharingEnabled(bool enabled)
     m_screenSharingEnabled = enabled;
 }
 
+bool RemoteDesktopSession::clipboardEnabled() const
+{
+    return m_clipboardEnabled;
+}
+
+void RemoteDesktopSession::setClipboardEnabled(bool enabled)
+{
+    m_clipboardEnabled = enabled;
+}
+
 void RemoteDesktopSession::setEisCookie(int cookie)
 {
     m_cookie = cookie;
@@ -335,7 +345,7 @@ void ScreenCastSession::streamClosed()
 
 GlobalShortcutsSession::GlobalShortcutsSession(QObject *parent, const QString &appId, const QString &path)
     : Session(parent, appId, path)
-    , m_token(path.mid(path.lastIndexOf('/') + 1))
+    , m_token(path.mid(path.lastIndexOf(u'/') + 1))
     , m_globalAccelInterface(
           new KGlobalAccelInterface(QStringLiteral("org.kde.kglobalaccel"), QStringLiteral("/kglobalaccel"), QDBusConnection::sessionBus(), this))
     , m_component(new KGlobalAccelComponentInterface(m_globalAccelInterface->service(),
@@ -384,7 +394,7 @@ GlobalShortcutsSession::GlobalShortcutsSession(QObject *parent, const QString &a
 
 GlobalShortcutsSession::~GlobalShortcutsSession() = default;
 
-void GlobalShortcutsSession::setActions(const Shortcuts &shortcuts)
+void GlobalShortcutsSession::setActions(const QList<ShortcutInfo> &shortcuts)
 {
     const QList<KGlobalShortcutInfo> shortcutInfos = m_component->allShortcutInfos();
     QHash<QString, KGlobalShortcutInfo> shortcutInfosByName;
@@ -394,33 +404,37 @@ void GlobalShortcutsSession::setActions(const Shortcuts &shortcuts)
     }
 
     for (const auto &shortcut : shortcuts) {
-        const QString description = shortcut.second["description"].toString();
-        if (description.isEmpty() || shortcut.first.isEmpty()) {
-            qCWarning(XdgSessionKdeSession) << "Shortcut without name or description" << shortcut.first << "for" << componentName();
+        if (shortcut.id.isEmpty()) {
+            qCWarning(XdgSessionKdeSession) << "Shortcut without id" << "for" << componentName();
+            continue;
+        }
+        if (shortcut.description.isEmpty()) {
+            qCWarning(XdgSessionKdeSession) << "Shortcut without name or description" << shortcut.id << "for" << componentName();
             continue;
         }
 
-        std::unique_ptr<QAction> &action = m_shortcuts[shortcut.first];
+        std::unique_ptr<QAction> &action = m_shortcuts[shortcut.id];
         if (!action) {
             action = std::make_unique<QAction>();
         }
+        const QString app = Utils::applicationName(m_appId);
         action->setProperty("componentName", componentName());
-        const KService::Ptr kservice = KService::serviceByDesktopName(m_appId);
-        action->setProperty("componentDisplayName", kservice ? kservice->name() : componentName());
-        action->setObjectName(shortcut.first);
-        action->setText(description);
-        const auto itShortcut = shortcutInfosByName.constFind(shortcut.first);
+        action->setProperty("componentDisplayName", app.isEmpty() ? componentName() : app);
+        action->setObjectName(shortcut.id);
+        action->setText(shortcut.description);
+        const auto itShortcut = shortcutInfosByName.constFind(shortcut.id);
         if (itShortcut != shortcutInfosByName.constEnd()) {
             action->setShortcuts(itShortcut->keys());
         } else {
-            const auto preferredShortcut = XdgShortcut::parse(shortcut.second["preferred_trigger"].toString());
-            if (preferredShortcut) {
-                action->setShortcut(preferredShortcut.value());
+            action->setShortcut(shortcut.keySequence);
+            if (!shortcut.preferredKeySequence.isEmpty()) {
+                KGlobalAccel::self()->setDefaultShortcut(action.get(), {shortcut.preferredKeySequence});
             }
         }
-        KGlobalAccel::self()->setGlobalShortcut(action.get(), action->shortcuts());
+        // If it's a new shortcut assign keySequence otherwise the old ones will be loaded.
+        KGlobalAccel::self()->setShortcut(action.get(), {shortcut.keySequence}, KGlobalAccel::Autoloading);
 
-        shortcutInfosByName.remove(shortcut.first);
+        shortcutInfosByName.remove(shortcut.id);
     }
 
     // We can forget the shortcuts that aren't around anymore
@@ -454,7 +468,7 @@ void GlobalShortcutsSession::loadActions()
             action = std::make_unique<QAction>();
         }
         action->setProperty("componentName", componentName());
-        action->setProperty("componentDisplayName", componentName());
+        action->setProperty("componentDisplayName", Utils::applicationName(m_appId));
         action->setObjectName(name);
         action->setText(info.friendlyName());
         action->setShortcuts(info.keys());
@@ -532,9 +546,9 @@ void InputCaptureSession::connect(const QDBusObjectPath &path)
     auto connectSignal = [this](const QString &signalName, const char *slot) {
         QDBusConnection::sessionBus().connect(kwinService(), m_kwinInputCapture.path(), kwinInputCaptureInterface(), signalName, this, slot);
     };
-    connectSignal("disabled", SIGNAL(disabled()));
-    connectSignal("activated", SIGNAL(activated(uint, QPointF)));
-    connectSignal("deactivated", SIGNAL(deactivated(uint)));
+    connectSignal(u"disabled"_s, SIGNAL(disabled()));
+    connectSignal(u"activated"_s, SIGNAL(activated(uint, QPointF)));
+    connectSignal(u"deactivated"_s, SIGNAL(deactivated(uint)));
 }
 
 QDBusPendingReply<void> InputCaptureSession::enable()
