@@ -8,9 +8,9 @@
  */
 
 #include "waylandintegration.h"
-#include "qwayland-wayland.h"
 #include "screencast.h"
 #include "screencasting.h"
+#include "wayland-wayland-client-protocol.h"
 #include "waylandintegration_debug.h"
 #include "waylandintegration_p.h"
 
@@ -36,14 +36,6 @@
 #include <KWayland/Client/registry.h>
 #include <KWayland/Client/surface.h>
 
-// system
-#include <fcntl.h>
-#include <linux/input-event-codes.h>
-#include <sys/mman.h>
-#include <unistd.h>
-#include <xkbcommon/xkbcommon.h>
-
-#include <qpa/qplatformnativeinterface.h>
 #include <waylandintegration_debug.h>
 
 Q_GLOBAL_STATIC(WaylandIntegration::WaylandIntegrationPrivate, globalWaylandIntegration)
@@ -51,7 +43,7 @@ Q_GLOBAL_STATIC(WaylandIntegration::WaylandIntegrationPrivate, globalWaylandInte
 namespace WaylandIntegration
 {
 FakeInput::FakeInput()
-    : QWaylandClientExtensionTemplate<FakeInput>(5)
+    : QWaylandClientExtensionTemplate<FakeInput>(6)
 {
     initialize();
 }
@@ -264,7 +256,7 @@ void WaylandIntegration::WaylandIntegrationPrivate::acquireStreamingInput(bool a
 WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startStreamingWindow(KWayland::Client::PlasmaWindow *window,
                                                                                                Screencasting::CursorMode cursorMode)
 {
-    return startStreaming(m_screencasting->createWindowStream(QString::fromLatin1(window->uuid()), cursorMode),
+    return startStreaming(m_screencasting->createWindowStream(window, cursorMode),
                           {{QLatin1String("source_type"), static_cast<uint>(ScreenCastPortal::Window)}});
 }
 
@@ -447,149 +439,14 @@ void WaylandIntegration::WaylandIntegrationPrivate::requestKeyboardKeycode(int k
     }
 }
 
-namespace
-{
-struct XKBStateDeleter {
-    void operator()(struct xkb_state *state) const
-    {
-        return xkb_state_unref(state);
-    }
-};
-struct XKBKeymapDeleter {
-    void operator()(struct xkb_keymap *keymap) const
-    {
-        return xkb_keymap_unref(keymap);
-    }
-};
-struct XKBContextDeleter {
-    void operator()(struct xkb_context *context) const
-    {
-        return xkb_context_unref(context);
-    }
-};
-using ScopedXKBState = std::unique_ptr<struct xkb_state, XKBStateDeleter>;
-using ScopedXKBKeymap = std::unique_ptr<struct xkb_keymap, XKBKeymapDeleter>;
-using ScopedXKBContext = std::unique_ptr<struct xkb_context, XKBContextDeleter>;
-}
-class Xkb : public QtWayland::wl_keyboard
-{
-public:
-    struct Code {
-        const uint32_t level;
-        const uint32_t code;
-    };
-    std::optional<Code> keycodeFromKeysym(xkb_keysym_t keysym)
-    {
-        /* The offset between KEY_* numbering, and keycodes in the XKB evdev
-         * dataset. */
-        static const uint EVDEV_OFFSET = 8;
-
-        auto layout = xkb_state_serialize_layout(m_state.get(), XKB_STATE_LAYOUT_EFFECTIVE);
-        const xkb_keycode_t max = xkb_keymap_max_keycode(m_keymap.get());
-        for (xkb_keycode_t keycode = xkb_keymap_min_keycode(m_keymap.get()); keycode < max; keycode++) {
-            uint levelCount = xkb_keymap_num_levels_for_key(m_keymap.get(), keycode, layout);
-            for (uint currentLevel = 0; currentLevel < levelCount; currentLevel++) {
-                const xkb_keysym_t *syms;
-                uint num_syms = xkb_keymap_key_get_syms_by_level(m_keymap.get(), keycode, layout, currentLevel, &syms);
-                for (uint sym = 0; sym < num_syms; sym++) {
-                    if (syms[sym] == keysym) {
-                        return Code{currentLevel, keycode - EVDEV_OFFSET};
-                    }
-                }
-            }
-        }
-        return {};
-    }
-
-    static Xkb *self()
-    {
-        static Xkb self;
-        return &self;
-    }
-
-private:
-    Xkb()
-    {
-        m_ctx.reset(xkb_context_new(XKB_CONTEXT_NO_FLAGS));
-        if (!m_ctx) {
-            qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "Failed to create xkb context";
-            return;
-        }
-        m_keymap.reset(xkb_keymap_new_from_names(m_ctx.get(), nullptr, XKB_KEYMAP_COMPILE_NO_FLAGS));
-        if (!m_keymap) {
-            qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "Failed to create the keymap";
-            return;
-        }
-        m_state.reset(xkb_state_new(m_keymap.get()));
-        if (!m_state) {
-            qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "Failed to create the xkb state";
-            return;
-        }
-
-        QPlatformNativeInterface *nativeInterface = qGuiApp->platformNativeInterface();
-        auto seat = static_cast<wl_seat *>(nativeInterface->nativeResourceForIntegration("wl_seat"));
-        init(wl_seat_get_keyboard(seat));
-    }
-
-    void keyboard_keymap(uint32_t format, int32_t fd, uint32_t size) override
-    {
-        if (format != WL_KEYBOARD_KEYMAP_FORMAT_XKB_V1) {
-            qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "unknown keymap format:" << format;
-            close(fd);
-            return;
-        }
-
-        char *map_str = static_cast<char *>(mmap(nullptr, size, PROT_READ, MAP_SHARED, fd, 0));
-        if (map_str == MAP_FAILED) {
-            close(fd);
-            return;
-        }
-
-        m_keymap.reset(xkb_keymap_new_from_string(m_ctx.get(), map_str, XKB_KEYMAP_FORMAT_TEXT_V1, XKB_KEYMAP_COMPILE_NO_FLAGS));
-        munmap(map_str, size);
-        close(fd);
-
-        if (m_keymap)
-            m_state.reset(xkb_state_new(m_keymap.get()));
-        else
-            m_state.reset(nullptr);
-    }
-
-    ScopedXKBContext m_ctx;
-    ScopedXKBKeymap m_keymap;
-    ScopedXKBState m_state;
-};
-
 void WaylandIntegration::WaylandIntegrationPrivate::requestKeyboardKeysym(int keysym, bool state)
 {
     if (m_fakeInput && m_fakeInput->isActive()) {
-        auto keycode = Xkb::self()->keycodeFromKeysym(keysym);
-        if (!keycode) {
-            qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "Failed to convert keysym into keycode" << keysym;
-            return;
+        if (state) {
+            m_fakeInput->keyboard_keysym(keysym, WL_KEYBOARD_KEY_STATE_PRESSED);
+        } else {
+            m_fakeInput->keyboard_keysym(keysym, WL_KEYBOARD_KEY_STATE_RELEASED);
         }
-
-        auto sendKey = [this, state](int keycode) {
-            if (state) {
-                m_fakeInput->keyboard_key(keycode, WL_KEYBOARD_KEY_STATE_PRESSED);
-            } else {
-                m_fakeInput->keyboard_key(keycode, WL_KEYBOARD_KEY_STATE_RELEASED);
-            }
-        };
-        switch (keycode->level) {
-        case 0:
-            break;
-        case 1:
-            sendKey(KEY_LEFTSHIFT);
-            break;
-        case 2:
-            sendKey(KEY_RIGHTALT);
-            break;
-        default:
-            qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "Unsupported key level" << keycode->level;
-            break;
-        }
-        sendKey(keycode->code);
     }
 }
 
