@@ -31,7 +31,6 @@ class Registry;
 class PlasmaWindow;
 class PlasmaWindowManagement;
 class RemoteBuffer;
-class XdgImporter;
 }
 }
 
@@ -63,7 +62,6 @@ private:
 
     KWayland::Client::Registry *m_registry = nullptr;
     KWayland::Client::PlasmaWindowManagement *m_windowManagement = nullptr;
-    KWayland::Client::XdgImporter *m_xdgImporter = nullptr;
 
 public:
     void authenticate();
@@ -74,10 +72,10 @@ public:
     void acquireStreamingInput(bool acquire);
 
     Stream startStreamingOutput(QScreen *screen, Screencasting::CursorMode mode);
-    Stream startStreamingWindow(const QMap<int, QVariant> &win, Screencasting::CursorMode mode);
+    Stream startStreamingWindow(KWayland::Client::PlasmaWindow *window, Screencasting::CursorMode mode);
     Stream startStreamingWorkspace(Screencasting::CursorMode mode);
     Stream startStreamingRegion(const QRect region, Screencasting::CursorMode mode);
-    Stream startStreamingVirtualOutput(const QString &name, const QSize &size, Screencasting::CursorMode mode);
+    Stream startStreamingVirtualOutput(const QString &name, const QString &description, const QSize &size, Screencasting::CursorMode mode);
     void stopStreaming(uint32_t nodeid);
 
     void requestPointerButtonPress(quint32 linuxButton);
@@ -96,7 +94,6 @@ public:
 
 private:
     Stream startStreaming(ScreencastingStream *stream, const QVariantMap &streamOptions);
-    bool eventFilter(QObject *watched, QEvent *event) override;
 
     uint m_streamInput = 0;
     bool m_waylandAuthenticationRequested = false;
